package com.shkj.wcs.mapper;


import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.shkj.wcs.domain.BasePunch;
import com.shkj.wcs.vo.BasePunchRecordVo;

import java.util.List;

/**
 * 冲孔机设定Mapper接口
 *
 * @author zjx
 * @date 2023-04-20
 */
public interface BasePunchMapper extends BaseMapper<BasePunch> {
    /**
     * 查询设备管理
     *
     * @param id 设备管理主键
     * @return 设备管理
     */
    public  BasePunch selectBasePunchById(Long id);

    /**
     * 查询设备管理列表
     *
     * @param BasePunch 设备管
     * @return 设备管理集合
     */
    public  List<BasePunch> selectBasePunchList(BasePunch BasePunch);

    /**
     * 新增设备管理
     *
     * @param BasePunch 设备管理
     * @return 结果
     */
    public int insertBasePunch(BasePunch BasePunch);

    /**
     * 修改设备管理
     *
     * @param BasePunch 设备管理
     * @return 结果
     */
    public int updateBasePunch(BasePunch BasePunch);

    /**
     * 删除设备管理
     *
     * @param id 设备管理主键
     * @return 结果
     */
    public int deleteBasePunchById(Long id);



    /**
     * 查询冲孔机的任务数量及状态
     *
     * @param basePunch 冲孔机设定
     * @return 冲孔机任务集合
     */
    public BasePunchRecordVo selectBasePunchRecord(BasePunch basePunch);
}
